cgexplore.topologies.CGM12L24
=============================

.. currentmodule:: cgexplore.topologies

.. autoclass:: CGM12L24
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CGM12L24.get_vertex_alignments
   
   

   
   
   